@@ -1,8 +1,11 @@
 # -*- coding: utf-8; tab-width: 4; indent-tabs-mode: t; python-indent: 4 -*-
 from pymongo import MongoClient
-from lisa.server.service import configuration
 from lisa.server.libs import LisaFactorySingleton
 
+from lisa.server.ConfigManager import ConfigManagerSingleton
+
+configuration = ConfigManagerSingleton.get().getConfiguration()
+
 
 class IPlugin(object):
     """
